
local MakePlayerCharacter = require "prefabs/player_common"


local assets = {

        Asset( "ANIM", "anim/player_basic.zip" ),
        Asset( "ANIM", "anim/player_idles_shiver.zip" ),
        Asset( "ANIM", "anim/player_actions.zip" ),
        Asset( "ANIM", "anim/player_actions_axe.zip" ),
        Asset( "ANIM", "anim/player_actions_pickaxe.zip" ),
        Asset( "ANIM", "anim/player_actions_shovel.zip" ),
        Asset( "ANIM", "anim/player_actions_blowdart.zip" ),
        Asset( "ANIM", "anim/player_actions_eat.zip" ),
        Asset( "ANIM", "anim/player_actions_item.zip" ),
        Asset( "ANIM", "anim/player_actions_uniqueitem.zip" ),
        Asset( "ANIM", "anim/player_actions_bugnet.zip" ),
        Asset( "ANIM", "anim/player_actions_fishing.zip" ),
        Asset( "ANIM", "anim/player_actions_boomerang.zip" ),
        Asset( "ANIM", "anim/player_bush_hat.zip" ),
        Asset( "ANIM", "anim/player_attacks.zip" ),
        Asset( "ANIM", "anim/player_idles.zip" ),
        Asset( "ANIM", "anim/player_rebirth.zip" ),
        Asset( "ANIM", "anim/player_jump.zip" ),
        Asset( "ANIM", "anim/player_amulet_resurrect.zip" ),
        Asset( "ANIM", "anim/player_teleport.zip" ),
        Asset( "ANIM", "anim/wilson_fx.zip" ),
        Asset( "ANIM", "anim/player_one_man_band.zip" ),
        Asset( "ANIM", "anim/shadow_hands.zip" ),
        Asset( "SOUND", "sound/sfx.fsb" ),
        Asset( "SOUND", "sound/wilson.fsb" ),
        Asset( "ANIM", "anim/beard.zip" ),

        Asset( "ANIM", "anim/palehuman.zip" ),
        Asset( "ANIM", "anim/ghost_palehuman_build.zip" ),
}
local prefabs = {}
local start_inv = {
	-- Custom starting items
	"tophat",
	"amulet",
	"nightsword",
}

-- This initializes for both clients and the host
local common_postinit = function(inst) 
	inst:AddTag("spiderwhisperer")
    inst:AddTag("monster")
	-- Minimap icon
	inst.MiniMapEntity:SetIcon( "palehuman.tex" )
end

local function updatestats(inst)

	if TheWorld.state.phase == "day" then
	
		inst.Light:Enable(false)
		inst.components.hunger:SetRate(TUNING.WILSON_HUNGER_RATE*0) --Barely Regen, Slower Hunger.
		inst.components.health:StartRegen(1, 12)  --1Hp, 1 seconds. 5hp/min. Day Regen is currently off.
		inst.components.combat.damagemultiplier = 0.8
		inst.components.health:SetMaxHealth(80)
		inst.components.locomotor.walkspeed = 4
		inst.components.locomotor.runspeed = 8
		
	elseif TheWorld.state.phase == "dusk" then
	
		inst.Light:Enable(false)
		inst.components.hunger:SetRate(TUNING.WILSON_HUNGER_RATE*1.5) --Faster Regen, Faster Hunger.
		inst.components.health:StartRegen(1, 6)  --1Hp, 6 seconds. 10hp/min.
		inst.components.combat.damagemultiplier = 1.5
		inst.components.health:SetMaxHealth(160)
		inst.components.locomotor.walkspeed = 6.8
		inst.components.locomotor.runspeed = 10.8
	
	
	elseif TheWorld.state.phase == "night" then
		
		inst.Light:Enable(true)
		
		inst.components.health:StartRegen(1, 3)  --1Hp, 3 seconds. 20hp/min.
		inst.components.hunger:SetRate(TUNING.WILSON_HUNGER_RATE*1.5) --Fast Regen, Fast Hunger.
		inst.components.combat.damagemultiplier = 2
		inst.components.health:SetMaxHealth(200)
		inst.components.locomotor.walkspeed = 8
		inst.components.locomotor.runspeed = 10.8
	
		if TheWorld.state.isfullmoon then
		
			inst.components.health:StartRegen(2, 0.75)  --2Hp, .75 seconds. 160hp/min.
			inst.components.hunger:SetRate(8*TUNING.WILSON_HUNGER_RATE)
			inst.components.combat.damagemultiplier = 6
			inst.components.health:SetMaxHealth(666)
			inst.components.locomotor.walkspeed = 12
			inst.components.locomotor.runspeed = 12
			inst.components.sanity.dapperness = TUNING.DAPPERNESS_SMALL * (-200)
			inst.components.talker:Say("The Full Moon calls to me.. and I shall answer with Blood.")
		
		end
	end
	
	inst.Light:SetRadius(10) 
	inst.Light:SetFalloff(0.75)
	inst.Light:SetIntensity(.6)		
	inst.Light:SetColour(235/255,12/255,12/255)
end

-- This initializes for the host only
local master_postinit = function(inst)
	-- Character Sound
	inst.talker_path_override = "dontstarve_DLC001/characters/"
	inst.soundsname = "webber"

	
	-- Stats	
	inst.components.health:SetMaxHealth(200)
	inst.components.hunger:SetMax(40)
	inst.components.sanity:SetMax(80)
	
	inst.components.locomotor.walkspeed = 6.8
	inst.components.locomotor.runspeed = 10.8
	
	
	inst.components.temperature.inherentinsulation = 48 --Cold Resistance. Tweaking Currently.
	
	inst.components.sanity.night_drain_mult = -69 --Sanity gained at night.
	inst.components.sanity.dapperness = TUNING.DAPPERNESS_SMALL * (-18) --Sanity lost during the day.

	--Carnivore. Somewhat able to eat Monster Meat.
	--inst.components.eater:SetCarnivore()
	inst.components.eater.strongstomach = true
	
	--local light = inst.entity:AddLight()
	--inst.Light:Enable(false)
	--inst.Light:SetRadius(15)
	--inst.Light:SetFalloff(0.75)
	--inst.Light:SetIntensity(.6)
	--inst.Light:SetColour(70/255,255/255,12/255)
	
	-- Watches for changes in the day/dusk/night
	inst:WatchWorldState("phase",updatestats)
	updatestats(inst)

end


return MakePlayerCharacter("palehuman", prefabs, assets, common_postinit, master_postinit, start_inv)
